<?php
/*
 * @wordpress-plugin
 * Plugin Name:       hockeydata LOS
 * Plugin URI:        https://api.hockeydata.net/docs/plugins/wordpress/
 * Description:       hockeydata Live.Online Statistics
 * Version:           1.0.0
 * Author:            hockeydata
 * Author URI:        http://www.hockeydata.net/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       hockeydata_los
 * Domain Path:       /languages
*/
define( 'HD_LOS_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

function los_init() {

	add_action( 'widgets_init', 'los_load_widgets' );
	add_action( 'plugins_loaded', 'los_load_textdomain' );
	add_action( 'wp_enqueue_scripts', 'los_register_styles' );

	if ( is_admin() ) {

		add_action('admin_print_scripts', 'los_admin_register_scripts');
		add_action('admin_print_styles', 'los_admin_register_styles');
		add_action('admin_init', 'los_register_settings');
		add_action('admin_menu', 'los_admin_menu');

	}

}

function los_load_widgets() {

	include( HD_LOS_PLUGIN_PATH . 'widgets/standings.php' );
	include( HD_LOS_PLUGIN_PATH . 'widgets/schedule.php' );

	register_widget( 'LOS_Widget_Standings' );
	register_widget( 'LOS_Widget_Schedule' );

}

function los_load_textdomain() {

	load_plugin_textdomain( 'hockeydata_los', false, basename( dirname( __FILE__ ) ) . '/languages' );

}

function los_register_settings() {

	register_setting( 'los_general_options', 'los_api_key' );
	register_setting( 'los_general_options', 'los_template' );

}

function los_register_styles() {

	$template = get_option( 'los_template' );

	if ( $template ) {

		wp_register_style( 'los-template', 'https://api.hockeydata.net/css/?los_template_' . esc_attr( $template ) );
		wp_enqueue_style( 'los-template' );

	}

}

function los_admin_load_page( $page ) {

	include( 'inc/admin-header.php' );
	include( 'pages/' . $page . '.php' );
	include( 'inc/admin-footer.php' );

}

function los_admin_register_scripts() {

	wp_register_script( 'los-admin-script', plugins_url( '/js/los-admin.js', __FILE__ ) );
	wp_enqueue_script( 'los-admin-script' );

}

function los_admin_register_styles() {

	wp_register_style( 'los-admin-style', plugins_url( '/css/los-admin.css', __FILE__ ) );
	wp_enqueue_style( 'los-admin-style' );

}

function los_admin_menu() {

	add_options_page( 'hockeydata Live.Online Statistics', 'LOS', 'administrator', 'hockeydata_los_settings', 'los_admin_menu_settings' );

}

function los_admin_menu_settings() {

	los_admin_load_page( 'settings' );

}

los_init();