<?php

class LOS_Widget_Schedule extends WP_Widget {

	function __construct() {

		parent::__construct( 'los_widget_schedule', __('hockeydata LOS: Schedule', 'hockeydata_los'), array( 'description' => __( 'hockeydata LOS: Schedule', 'hockeydata_los' ) ) );

	}

	public function widget( $args, $instance ) {

		$title = $instance[ 'title' ];

		$options = array(

			'apiKey' => esc_attr( get_option( 'los_api_key' ) ),
			'divisionId' => $instance[ 'divisionId' ],
			'sport' => $instance[ 'sport' ],
			'league' => $instance[ 'league' ],
			'autoReload' => intval( $instance[ 'autoReload' ] ) ? true : false,
			"showLegend" => intval( $instance[ 'showLegend' ] ) ? true : false,
			"autoShowLegend" => intval( $instance[ 'autoShowLegend' ] ) ? true : false,
			'columnSet' => $instance[ 'columnSet' ]

		);

		if ( $instance[ 'futureOnly' ] ) {

			$options[ 'futureOnly' ] = true;

		}

		if ( $instance[ 'showLegendText' ] ) {

			$options[ 'showLegendText' ] = $instance[ 'showLegendText' ];

		}

		if ( $instance[ 'hideLegendText' ] ) {

			$options[ 'hideLegendText' ] = $instance[ 'hideLegendText' ];

		}

		if ( $instance[ 'limit' ] ) {

			$options[ 'limit' ] = intval( $instance[ 'limit' ] );

		}

		if ( $instance[ 'rowLink' ] ) {

			$options[ 'rowLink' ] = $instance[ 'rowLink' ];

		}

		if ( $instance[ 'textNoData' ] ) {

			$options[ 'textNoData' ] = $instance[ 'textNoData' ];

		}

		if ( $instance[ 'columns' ] ) {

			$options[ 'columns' ] = $instance[ 'columns' ];

		}

		if ( $instance[ 'additionalColumns' ] ) {

			$options[ 'additionalColumns' ] = $instance[ 'additionalColumns' ];

		}

		?>

		<script src="https://api.hockeydata.net/js/?los_schedule&los_configuration_<?php echo $instance[ 'sport' ]; ?>" type="text/javascript"></script>

		<aside class="widget">

			<?php if ( $title ) { ?><h1 class="widget-title"><?php echo $title; ?></h1><?php } ?>

			<div data-hd-widget="hockeydata.los.Schedule" data-hd-widget-options='<?php echo json_encode( $options ); ?>' id="<?php echo $args[ 'id' ]; ?>"></div>

		</aside>

		<?php
	}

	public function form( $instance ) {

		$title = isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '';
		$sport = isset( $instance[ 'sport' ] ) ? $instance[ 'sport' ] : '';
		$league = isset( $instance[ 'league' ] ) ? $instance[ 'league' ] : '';
		$divisionId = isset( $instance[ 'divisionId' ] ) ? $instance[ 'divisionId' ] : '';
		$autoReload = isset( $instance[ 'autoReload' ] ) ? intval( $instance[ 'autoReload' ] ) : 0;
		$futureOnly = isset( $instance[ 'futureOnly' ] ) ? intval( $instance[ 'futureOnly' ] ) : 0;
		$showLegend = isset( $instance[ 'showLegend' ] ) ? intval( $instance[ 'showLegend' ] ) : 0;
		$autoShowLegend = isset( $instance[ 'autoShowLegend' ] ) ? intval( $instance[ 'autoShowLegend' ] ) : 0;
		$showLegendText = isset( $instance[ 'showLegendText' ] ) ? $instance[ 'showLegendText' ] : '';
		$hideLegendText = isset( $instance[ 'hideLegendText' ] ) ? $instance[ 'hideLegendText' ] : '';
		$limit = isset( $instance[ 'limit' ] ) ? $instance[ 'limit' ] : '';
		$rowLink = isset( $instance[ 'rowLink' ] ) ? $instance[ 'rowLink' ] : '';
		$textNoData = isset( $instance[ 'textNoData' ] ) ? $instance[ 'textNoData' ] : '';
		$columns = isset( $instance[ 'columns' ] ) ? $instance[ 'columns' ] : '';
		$columnSet = isset( $instance[ 'columnSet' ] ) ? $instance[ 'columnSet' ] : '';
		$additionalColumns = isset( $instance[ 'additionalColumns' ] ) ? $instance[ 'additionalColumns' ] : '';

		?>
		<p>

			<label>

				<?php _e( 'Title', 'hockeydata_los' ); ?>

				<input name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" class="widefat">

			</label>

		</p>

		<p>

			<label>

				<?php _e( 'Sport', 'hockeydata_los' ); ?>

				<select name="<?php echo $this->get_field_name( 'sport' ); ?>" class="widefat">

					<option value=""<?php if ( ! $sport ) { ?> selected="selected" <?php } ?>></option>

					<option value="americanfootball"<?php if ( $sport == 'americanfootball' ) { ?> selected="selected" <?php } ?>><?php _e( 'American Football', 'hockeydata_los' ); ?></option>

					<option value="icehockey"<?php if ( $sport == 'icehockey' ) { ?> selected="selected" <?php } ?>><?php _e( 'Icehockey', 'hockeydata_los' ); ?></option>

				</select>

			</label>

		</p>

		<p>

			<label>

				<?php _e( 'League / Federation', 'hockeydata_los' ); ?>

				<select name="<?php echo $this->get_field_name( 'league' ); ?>" class="widefat">

					<option value=""<?php if ( ! $league ) { ?> selected="selected" <?php } ?>></option>

					<option value="afboe"<?php if ( $league == 'afboe' ) { ?> selected="selected" <?php } ?>><?php _e( 'Austrian Football League (AFB&Ouml;)', 'hockeydata_los' ); ?></option>

					<option value="ebel"<?php if ( $league == 'ebel' ) { ?> selected="selected" <?php } ?>><?php _e( 'Erste Bank Eishockey Liga (EBEL)', 'hockeydata_los' ); ?></option>

				</select>

			</label>

		</p>

		<p>

			<label>

				<?php _e( 'Division Id', 'hockeydata_los' ); ?>

				<input name="<?php echo $this->get_field_name( 'divisionId' ); ?>" type="text" value="<?php echo $divisionId; ?>" class="widefat">

			</label>

		</p>

		<p><a href="#" id="hockeydata_los_widget_schedule_<?php echo $this->id; ?>_additionalOptionsToggle"><?php _e( 'Additional Options', 'hockeydata_los' ); ?></a></p>

		<div id="hockeydata_los_widget_schedule_<?php echo $this->id; ?>_additionalOptions" style="display: none;">

			<p>

				<label>

					<input name="<?php echo $this->get_field_name( 'autoReload' ); ?>" type="checkbox" value="1"<?php if ( $autoReload ) { ?> checked="checked" <?php } ?>>

					<?php _e( 'Auto Reload', 'hockeydata_los' ); ?>

				</label>

			</p>

			<p>

				<label>

					<input name="<?php echo $this->get_field_name( 'futureOnly' ); ?>" type="checkbox" value="1"<?php if ( $futureOnly ) { ?> checked="checked" <?php } ?>>

					<?php _e( 'Show future Games only', 'hockeydata_los' ); ?>

				</label>

			</p>

			<p>

				<label>

					<input name="<?php echo $this->get_field_name( 'showLegend' ); ?>" id="<?php echo $this->get_field_id( 'showLegend' ); ?>" type="checkbox" value="1"<?php if ( $showLegend ) { ?> checked="checked" <?php } ?>>

					<?php _e( 'Show Legend', 'hockeydata_los' ); ?>

				</label>

			</p>

			<div id="hockeydata_los_widget_schedule_<?php echo $this->id; ?>_legendOptions"<?php if ( ! $showLegend ) { ?> style="display: none;" <?php } ?>>

				<p>

					<label>

						<input name="<?php echo $this->get_field_name( 'autoShowLegend' ); ?>" type="checkbox" value="1"<?php if ( $autoShowLegend ) { ?> checked="checked" <?php } ?>>

						<?php _e( 'Show Legend automatically', 'hockeydata_los' ); ?>

					</label>

				</p>

				<p>

					<label>

						<?php _e( 'Text for "Show Legend"', 'hockeydata_los' ); ?>

						<input name="<?php echo $this->get_field_name( 'showLegendText' ); ?>" type="text" value="<?php echo $showLegendText; ?>" class="widefat">

					</label>

				</p>

				<p>

					<label>

						<?php _e( 'Text for "Hide Legend"', 'hockeydata_los' ); ?>

						<input name="<?php echo $this->get_field_name( 'hideLegendText' ); ?>" type="text" value="<?php echo $hideLegendText; ?>" class="widefat">

					</label>

				</p>

			</div>

			<p>

				<label>

					<?php _e( 'Maximum Number of Games to be displayed (leave empty to display all)', 'hockeydata_los' ); ?>

					<input name="<?php echo $this->get_field_name( 'limit' ); ?>" type="number" value="<?php if ( $limit ) { echo $limit; } ?>" class="widefat">

				</label>

			</p>

			<p>

				<label>

					<?php _e( 'Row Link', 'hockeydata_los' ); ?>

					<input name="<?php echo $this->get_field_name( 'rowLink' ); ?>" type="text" value="<?php echo $rowLink; ?>" class="widefat">

				</label>

			</p>

			<p>

				<label>

					<?php _e( 'Text to be displayed if no data is available', 'hockeydata_los' ); ?>

					<input name="<?php echo $this->get_field_name( 'textNoData' ); ?>" type="text" value="<?php echo $textNoData; ?>" class="widefat">

				</label>

			</p>

			<p>

				<label>

					<?php _e( 'Columns', 'hockeydata_los' ); ?>

					<input name="<?php echo $this->get_field_name( 'columns' ); ?>" type="text" value="<?php echo $columns; ?>" class="widefat">

				</label>

			</p>

			<p>

				<label>

					<?php _e( 'Column Set', 'hockeydata_los' ); ?>

					<select name="<?php echo $this->get_field_name( 'columnSet' ); ?>" class="widefat">

						<option value="default"<?php if ( $columnSet == 'default' ) { ?> selected="selected" <?php } ?>><?php _e( 'Default', 'hockeydata_los' ); ?></option>

						<option value="short"<?php if ( $columnSet == 'short' ) { ?> selected="selected" <?php } ?>><?php _e( 'Short', 'hockeydata_los' ); ?></option>

						<option value="long"<?php if ( $columnSet == 'long' ) { ?> selected="selected" <?php } ?>><?php _e( 'Long', 'hockeydata_los' ); ?></option>

					</select>

				</label>

			</p>

			<p>

				<label>

					<?php _e( 'Additional Columns', 'hockeydata_los' ); ?>

					<input name="<?php echo $this->get_field_name( 'additionalColumns' ); ?>" type="text" value="<?php echo $additionalColumns; ?>" class="widefat">

				</label>

			</p>

			<p><a href="https://api.hockeydata.net/docs/javascript-api/hockeydata-los-schedule/" target="_blank">&raquo; <?php _e( 'More information about this widget and its options is available on the API documentation website.', 'hockeydata_los' ); ?></a></p>

		</div>

		<script>

			losWidgetFormSchedule( '<?php echo $this->id; ?>', '<?php echo $this->get_field_id( 'showLegend' ); ?>' );

		</script>

		<?php
	}

	public function update( $new_instance, $old_instance ) {

		$instance = array();

		$instance[ 'title' ] = ( ! empty( $new_instance[ 'title' ] ) ) ? strip_tags( $new_instance[ 'title' ] ) : '';
		$instance[ 'sport' ] = ( ! empty( $new_instance[ 'sport' ] ) ) ? strip_tags( $new_instance[ 'sport' ] ) : '';
		$instance[ 'league' ] = ( ! empty( $new_instance[ 'league' ] ) ) ? strip_tags( $new_instance[ 'league' ] ) : '';
		$instance[ 'divisionId' ] = ( ! empty( $new_instance[ 'divisionId' ] ) ) ? strip_tags( $new_instance[ 'divisionId' ] ) : '';
		$instance[ 'autoReload' ] = ( ! empty( $new_instance[ 'autoReload' ] ) ) ? intval( $new_instance[ 'autoReload' ] ) : 0;
		$instance[ 'futureOnly' ] = ( ! empty( $new_instance[ 'futureOnly' ] ) ) ? intval( $new_instance[ 'futureOnly' ] ) : 0;
		$instance[ 'showLegend' ] = ( ! empty( $new_instance[ 'showLegend' ] ) ) ? intval( $new_instance[ 'showLegend' ] ) : 0;
		$instance[ 'autoShowLegend' ] = ( ! empty( $new_instance[ 'autoShowLegend' ] ) ) ? intval( $new_instance[ 'autoShowLegend' ] ) : 0;
		$instance[ 'showLegendText' ] = ( ! empty( $new_instance[ 'showLegendText' ] ) ) ? strip_tags( $new_instance[ 'showLegendText' ] ) : '';
		$instance[ 'hideLegendText' ] = ( ! empty( $new_instance[ 'hideLegendText' ] ) ) ? strip_tags( $new_instance[ 'hideLegendText' ] ) : '';
		$instance[ 'limit' ] = ( ! empty( $new_instance[ 'limit' ] ) ) ? intval( $new_instance[ 'limit' ] ) : '';
		$instance[ 'rowLink' ] = ( ! empty( $new_instance[ 'rowLink' ] ) ) ? strip_tags( $new_instance[ 'rowLink' ] ) : '';
		$instance[ 'textNoData' ] = ( ! empty( $new_instance[ 'textNoData' ] ) ) ? strip_tags( $new_instance[ 'textNoData' ] ) : '';
		$instance[ 'columns' ] = ( ! empty( $new_instance[ 'columns' ] ) ) ? strip_tags( $new_instance[ 'columns' ] ) : '';
		$instance[ 'columnSet' ] = ( ! empty( $new_instance[ 'columnSet' ] ) ) ? strip_tags( $new_instance[ 'columnSet' ] ) : '';
		$instance[ 'additionalColumns' ] = ( ! empty( $new_instance[ 'additionalColumns' ] ) ) ? strip_tags( $new_instance[ 'additionalColumns' ] ) : '';

		return $instance;

	}
}